XButtonLook class
Resolved button defaults for a given XLook.
- Annotations
Constructors
- XButtonLook({required double radius, required XButtonStyle style})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- radius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → XButtonStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
XLook look) → XButtonLook