Consistent helpers for custom modal sheets and action sheets.
Pass look to opt into a visual preset. Default is XLook.standard.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
actions<
T> (BuildContext context, {required List< XBottomSheetAction< actions, String? title, String? message, String cancelLabel = 'Cancel', bool showCancel = true, XLook look = XLook.standard}) → Future<T> >T?> - Shows a typed list of actions and returns the selected value.
-
show<
T> (BuildContext context, {required WidgetBuilder builder, bool isScrollControlled = false, bool useSafeArea = true, bool? showDragHandle, bool isDismissible = true, bool enableDrag = true, Color? backgroundColor, ShapeBorder? shape, BoxConstraints? constraints, RouteSettings? routeSettings, XLook look = XLook.standard}) → Future< T?> - Shows arbitrary modal bottom-sheet content.