widgets/x_button library
Classes
- XButton
- A customizable button supporting idle, loading, success, and error states, icons, custom content, rounded style, and native button configuration.
Enums
- XButtonState
- Visual states supported directly by XButton.
Functions
-
styleButtonRounded(
{double radius = 10, Color? background, Color? foreground, Color? borderColor, bool? isEnable = true, double elevation = 1, double paddingHorizontal = 12, double paddingVertical = 5, double borderWidth = 0}) → ButtonStyle - Creates a rounded ButtonStyle used by XButton.