background property
Background color of the card container.
If not provided, it uses the active look preset or
Theme.of(context).canvasColor for XLook.standard.
Implementation
final Color? background;
Background color of the card container.
If not provided, it uses the active look preset or
Theme.of(context).canvasColor for XLook.standard.
final Color? background;