XBreakpoints class

Width thresholds used to select a responsive layout.

Constructors

XBreakpoints({double tablet = 600, double desktop = 1024})
const

Properties

desktop double
Minimum logical width classified as desktop.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet double
Minimum logical width classified as tablet.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(double width) XResponsiveSize
Resolves a width to its responsive category.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited