XScrollPage<T> class

A page returned by an XScrollFetcher.

Constructors

XScrollPage({required List<T> items, bool? hasMore})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool?
Whether another page is available.
final
items List<T>
Items returned for the current request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited