hasMore property
Whether another page is available.
When omitted, XScrollView infers it from whether items contains at least the requested number of items.
Implementation
final bool? hasMore;
Whether another page is available.
When omitted, XScrollView infers it from whether items contains at least the requested number of items.
final bool? hasMore;