XScrollRequest class
Describes one data request made by XScrollView.
Constructors
- XScrollRequest({required int page, required int offset, required int limit, required bool isRefresh})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRefresh → bool
-
Whether this request was triggered by pull-to-refresh.
final
- limit → int
-
Maximum number of items requested for this load.
final
- offset → int
-
Number of items already loaded.
final
- page → int
-
One-based page number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited