onLoadMore property
Fetches the next page when the remaining scroll extent reaches paginationThreshold.
Implementation
final XScrollFetcher<T>? onLoadMore;
Fetches the next page when the remaining scroll extent reaches paginationThreshold.
final XScrollFetcher<T>? onLoadMore;