XBottomSheetAction<T> class
One selectable action displayed by XBottomSheet.actions.
Constructors
Properties
- enabled → bool
-
Whether this action can be selected.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
Optional leading icon.
final
- isDestructive → bool
-
Applies the theme error color to the action.
final
- label → String
-
Main action label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional supporting label.
final
- value → T
-
Result returned when selected.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited